% AMASbook document class -- version: July 2003
% LaTeX document class for "AMAS Lecture Notes" (book style) 
% 2003(c)Tomasz G. Zielinski (Warsaw, Poland)
% Modified by M. Stanczyk to fill the requirements of abiomed lecture notes
%


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ABMbook}[2003/07/15 -- style for abiomed Lecture Notes, single author]
\DeclareOption{oneside}{\OptionNotUsed}
\DeclareOption{twocolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}
\ProcessOptions\relax
\LoadClass[twoside]{book}
\frenchspacing

%===== REQUIRED PACKAGES ==========================================
\RequirePackage{amsmath}[2000/06/06]
 %\setlength\multlinetaggap{6\p@}
  \setlength\multlinegap{\z@}
\RequirePackage{amsthm}[2000/06/02]
%==================================================================

%===== DIMENSIONS =================================================
\DeclareOption{10pt}{\setlength\textheight{46\baselineskip}}
\DeclareOption{11pt}{\setlength\textheight{40\baselineskip}}
\DeclareOption{12pt}{\setlength\textheight{36\baselineskip}}
\ProcessOptions\relax

\setlength\voffset{-1in}
\setlength\hoffset{-1in}

\setlength\paperwidth{166mm}
\setlength\paperheight{236mm}
\setlength\textwidth{127mm}
\setlength\oddsidemargin{22mm}
\setlength\evensidemargin{\oddsidemargin}
\setlength\topmargin{18mm}
\setlength\headheight{12\p@}
\setlength\headsep{3mm}
\setlength\topskip{1.2\baselineskip}
\advance\textheight\topskip
\setlength\footskip{40mm}  %\setlength\footskip{10mm}

\setlength\parindent{1.5em}
\setlength\parskip{0\p@}
\setlength\itemsep{0\p@}
\setlength\partopsep{3\p@}
\setlength\topsep{0\p@}
%==================================================================

%===== SECTIONING =================================================
\renewcommand\thepart          {\Roman{part}}
\renewcommand\thechapter       {\arabic{chapter}}
\renewcommand\thesection       {\thechapter.\arabic{section}}
\renewcommand\thesubsection    {\thesection.\arabic{subsection}}
\renewcommand\thesubsubsection {\thesubsection.\arabic{subsubsection}}
\renewcommand\theparagraph     {\thesubsubsection.\arabic{paragraph}}
\renewcommand\thesubparagraph  {\theparagraph.\arabic{subparagraph}}

\setcounter{secnumdepth}{2}

\def\section{\@startsection{section}{1}%
  {\parindent}{1.5\baselineskip\@plus.5\baselineskip}{.6\baselineskip}%
  {\normalfont\large\bfseries}}
\def\subsection{\@startsection{subsection}{2}%
  {\parindent}{1.2\baselineskip\@plus.4\baselineskip}{.5em}%
  {\normalfont\bfseries}}
\def\subsubsection{\@startsection{subsubsection}{3}%
  {\parindent}{.9\baselineskip\@plus.3\baselineskip}{-.7em}%
  {\normalfont\bfseries}}
\def\paragraph{\@startsection{paragraph}{4}%
  {\parindent}{.6\baselineskip\@plus.2\baselineskip}{.3em}%
  {\normalfont\itshape}}
\def\subparagraph{\@startsection{subparagraph}{5}%
  {\parindent}{.6\baselineskip\@plus.2\baselineskip}{-.5em}%
  {\normalfont\itshape}}
  
\def\@seccntformat#1{\csname the#1\endcsname.\hskip1.2ex}

\def\@sect#1#2#3#4#5#6[#7]{%
  \@ifnextchar[{\@iiSect{#1}{#2}{#3}{#4}{#5}{#6}[#7]}{\@iSect{#1}{#2}{#3}{#4}{#5}{#6}[#7]}}
  
\def\@iSect#1#2#3#4#5#6[#7]#8{\@Sect{#1}{#2}{#3}{#4}{#5}{#6}{#7}{#8}{#8}}
\def\@iiSect#1#2#3#4#5#6[#7][#8]#9{\@Sect{#1}{#2}{#3}{#4}{#5}{#6}{#7}{#8}{#9}}

\def\@Sect#1#2#3#4#5#6#7#8#9{%
  \ifnum #2>\c@secnumdepth
    \let\@svsec\@empty
  \else
    \refstepcounter{#1}%
    \protected@edef\@svsec{\@seccntformat{#1}\relax}%
  \fi
  \@tempskipa #5\relax
  \ifdim \@tempskipa>\z@
    \begingroup
      #6{%
        \@hangfrom{\hskip #3\relax\@svsec}%
          \interlinepenalty \@M #9\@@par}%
    \endgroup
    \csname #1mark\endcsname{#7}%
    \addcontentsline{toc}{#1}{%
      \ifnum #2>\c@secnumdepth \else
        \protect\numberline{\csname the#1\endcsname}%
      \fi
      #8}%
  \else
    \def\@svsechd{%
      #6{\hskip #3\relax
      \@svsec #8}%
      \csname #1mark\endcsname{#7}%
      \addcontentsline{toc}{#1}{%
        \ifnum #2>\c@secnumdepth \else
          \protect\numberline{\csname the#1\endcsname}%
        \fi
        #8}}%
  \fi
  \@xsect{#5}}
%==================================================================

%===== HEADINGS ===================================================
\newcommand\@headrule[1]{\small#1\hskip-\hsize\rule[-1mm]{\hsize}{.4\p@}}

\def\ps@headings{%
    \let\@oddfoot\@empty\let\@evenfoot\@empty
    \def\@evenhead{\@headrule{{\large\thepage}\hspace{2ex}\hfil{\small\scshape\leftmark}\hfil\hspace{2ex}}}%
    \def\@oddhead{\@headrule{\hspace{2ex}\hfil{\small\scshape\rightmark}\hfil\hspace{2ex}{\large\thepage}}}%
    \let\@mkboth\markboth
  \def\chaptermark##1{%
    \markboth{%
      \ifnum \c@secnumdepth >\m@ne
        \if@mainmatter
          \thechapter.\ %
        \fi
      \fi
      ##1}{%
      \ifnum \c@secnumdepth >\m@ne
        \if@mainmatter
          \thechapter.\ %
        \fi
      \fi
      ##1}}%
  \def\sectionmark##1{%
    \markright{%
      \ifnum \c@secnumdepth >\z@
        \thesection.\ %
      \fi
      ##1}}%
}

\newif\if@vacat

\def\ps@Empty{\let\@mkboth\@gobbletwo
     \let\@oddhead\@empty\def\@oddfoot{\reset@font\hfil[\thepage]
     %\if@vacat\@vacatfalse ~(poprz. strona: VACAT!)\fi
     \hfil}\let\@evenhead\@empty\let\@evenfoot\@oddfoot}
     
%\let\ps@Empty\ps@empty

\pagestyle{headings}
%==================================================================

%===== PART =======================================================
\newcommand{\newoddpage}{\ifodd\c@page\else\@vacattrue\stepcounter{page}\fi}

\renewcommand\part{%
  \clearpage\newoddpage
  \thispagestyle{Empty}%
  \if@twocolumn
    \onecolumn
    \@tempswatrue
  \else
    \@tempswafalse
  \fi
  \null\vfil
  \secdef\@part\@spart}

\def\@part[#1]#2{%
    \ifnum \c@secnumdepth >-2\relax
      \refstepcounter{part}%
      \addcontentsline{toc}{part}{\MakeUppercase{\partname~\thepart.}\hspace{1em}#1}%
    \else
      \addcontentsline{toc}{part}{#1}%
    \fi
    \markboth{}{}%
    {\centering
     \interlinepenalty \@M
     \normalfont
     \ifnum \c@secnumdepth >-2\relax
       \Large\bfseries \MakeUppercase{\partname~\thepart}
       \par
       \vskip 50\p@
     \fi
     \huge\bfseries #2\par}%
     \vfil%\@endpart
     }
%==================================================================

%===== CHAPTER ====================================================
\renewcommand\chapter{\clearpage\newoddpage
                      \thispagestyle{Empty}%\thispagestyle{plain}%
                      \global\@topnum\z@
                      \@afterindentfalse
                      \secdef\@chapter\@schapter}

\def\@chapter[#1]{%
  \@ifnextchar[{\@iiChapter[#1]}{\@iChapter[#1]}}
  
\def\@iChapter[#1]#2{\@Chapter{#1}{#2}{#2}}
\def\@iiChapter[#1][#2]#3{\@Chapter{#1}{#2}{#3}}

\def\@Chapter#1#2#3{\ifnum \c@secnumdepth >\m@ne
                       \if@mainmatter
                         \refstepcounter{chapter}%
                         \typeout{\@chapapp\space\thechapter.}%
                         \addcontentsline{toc}{chapter}%
                                   {\protect\numberline{\thechapter}#2}%
                       \else
                         \addcontentsline{toc}{chapter}{#2}%
                       \fi
                    \else
                      \addcontentsline{toc}{chapter}{#2}%
                    \fi
                    \chaptermark{#1}%
                    \addtocontents{lof}{\protect\addvspace{10\p@}}%
                    \addtocontents{lot}{\protect\addvspace{10\p@}}%
                    \if@twocolumn
                      \@topnewpage[\@makechapterhead{#3}]%
                    \else
                      \@makechapterhead{#3}%
                      \@afterheading
                    \fi}

\def\@makechapterhead#1{%
  %\thispagestyle{Empty}%
  \vspace*{30\p@}%
  {\parindent \z@ \raggedright \normalfont
    \ifnum \c@secnumdepth >\m@ne
      \if@mainmatter
        \centering \large\bfseries \@chapapp\space \Huge\thechapter
        \par\nobreak
        \vskip 20\p@
      \fi
    \fi
    \interlinepenalty\@M
    \centering
    \parbox{0.8\textwidth}{\centering\LARGE\bfseries #1\par}\nobreak
    \vskip 10\p@
    \rule{0.8\textwidth}{0.5mm}
    \vskip 50\p@
  }}

\def\@schapter#1{\if@twocolumn
                   \@topnewpage[\@makeschapterhead{#1}]%
                 \else
                   \@makeschapterhead{#1}%
                   \@afterheading
                 \fi
                 \@mkboth{#1}{#1}}

\def\@makeschapterhead#1{%
  %\thispagestyle{Empty}%
  \vspace*{30\p@}%
  {\parindent \z@ \raggedright
    \normalfont
    \interlinepenalty\@M
    \centering 
    \parbox{0.8\textwidth}{\centering \LARGE\bfseries #1\par}\nobreak
    \vskip 10\p@
    \rule{0.8\textwidth}{0.5mm}
    \vskip 50\p@
  }}
%==================================================================

%===== APPENDIX ===================================================
\renewcommand\appendix{%
   \setcounter{chapter}{0}
   \renewcommand{\chaptername}{\appendixname}
   \renewcommand{\thechapter}{\Alph{chapter}}
   }
%==================================================================

%===== LISTS ======================================================
\def\itemize{%
  \ifnum \@itemdepth >\thr@@\@toodeep\else
    \advance\@itemdepth\@ne
    \edef\@itemitem{labelitem\romannumeral\the\@itemdepth}%
    \expandafter
    \list
      \csname\@itemitem\endcsname
      {\itemsep2\p@ \parsep\z@ \topsep2\p@ \partopsep\z@
       \def\makelabel##1{\hss\llap{##1}}}%
  \fi}
\let\enditemize =\endlist

\def\enumerate{%
  \ifnum \@enumdepth >\thr@@\@toodeep\else
    \advance\@enumdepth\@ne
    \edef\@enumctr{enum\romannumeral\the\@enumdepth}%
      \expandafter
      \list 
        \csname label\@enumctr\endcsname
        {\usecounter\@enumctr
         \itemsep2\p@  \parsep\z@ \topsep2\p@ \partopsep\z@
         \def\makelabel##1{\hss\llap{##1}}}%
  \fi}

\renewenvironment{description}
               {\list{}{\labelwidth\z@ \itemindent-\leftmargin
                        \itemsep2\p@  \parsep\z@ \topsep2\p@ \partopsep\z@
                        \let\makelabel\descriptionlabel}}
               {\endlist}
%==================================================================

%===== NEWTHEOREMS ================================================
\newtheoremstyle{thmLemDef}% name
  {4pt}%      Space above
  {4pt}%      Space below
  {\itshape}% Body font
  {\parindent}%         Indent amount (empty = no indent, \parindent = para indent)
  {\bf}%      Thm head font
  {:}%        Punctuation after thm head
  {.5em}%     Space after thm head: " " = normal interword space;
        %       \newline = linebreak
  {}%         Thm head spec (can be left empty, meaning `normal')
  
\theoremstyle{thmLemDef}
 \newtheorem{theorem}{Theorem}[chapter]
 %\newtheorem{lemma}[theorem]{Lemma}
 \newtheorem{lemma}{Lemma}[chapter]
 \newtheorem{definition}{Definition}
 \newtheorem*{theorem*}{Theorem}
 \newtheorem*{lemma*}{Lemma}
 \newtheorem*{definition*}{Definition}
 

\newtheoremstyle{ex}% name
  {8pt}%        Space above
  {8pt}%        Space below
  {\sl}%        Body font
  {\parindent}% Indent amount (empty = no indent, \parindent = para indent)
  {\bf}%        Thm head font
  {:}%          Punctuation after thm head
  {.5em}%       Space after thm head: " " = normal interword space; \newline = linebreak
  {}%           Thm head spec (can be left empty, meaning `normal')

\theoremstyle{ex}
\newtheorem{example}{Example}[chapter]
\newtheorem{exercise}{Exercise}[chapter]
\newtheorem*{example*}{Example}
\newtheorem*{exercise*}{Exercise}


\newtheoremstyle{other}% name
  {4pt}%      Space above
  {4pt}%      Space below
  {}%         Body font
  {\parindent}%         Indent amount (empty = no indent, \parindent = para indent)
  {\bf}%      Thm head font
  {.}%        Punctuation after thm head
  {.5em}%     Space after thm head: " " = normal interword space;
        %       \newline = linebreak
  {}%         Thm head spec (can be left empty, meaning `normal')
  
\theoremstyle{other}
 \newtheorem{case}{Case}[chapter]
 \newtheorem{corollary}{Corollary}[chapter]
 \newtheorem{remark}{Remark}[chapter]
 \newtheorem{observation}{Observation}[chapter]
 \newtheorem{proposition}{Proposition}[chapter]
 \newtheorem*{case*}{Case}
 \newtheorem*{corollary*}{Corollary}
 \newtheorem*{remark*}{Remark}
 \newtheorem*{observation*}{Observation}
 \newtheorem*{proposition*}{Proposition}
 
\renewcommand{\qed}{\hfill$\blacksquare$}

\renewenvironment{proof}[1][]{\par
  \pushQED{\qed}%
  \normalfont
  \trivlist
  \item[\hskip\labelsep
        \indent\bf
    \proofname\@ifempty{#1}{}{~~(#1)}\@addpunct{.}]\ignorespaces
}{%
  \popQED\endtrivlist\@endpefalse
}
  
\newenvironment{proof*}[1][]{\par
  \normalfont
  \trivlist
  \item[\hskip\labelsep
        \indent\bf
    \proofname\@ifempty{#1}{}{~~(#1)}\@addpunct{.}]\ignorespaces
}{%
  \endtrivlist\@endpefalse
}
  
\renewcommand{\proofname}{Proof}
%==================================================================

%===== EQUATION ENVIRONMENTS ======================================
\def\@textsubscript#1{%
  {\m@th\ensuremath{_{\mbox{\fontsize\sf@size\z@#1}}}}}

\newenvironment{subnumbered}{%
  \refstepcounter{equation}%
  \protected@edef\theparentequation{\theequation}%
  \setcounter{parentequation}{\value{equation}}%
  \setcounter{equation}{0}%
  \def\theequation{\theparentequation\@textsubscript{\footnotesize\arabic{equation}}}%
  \ignorespaces
}{%
  \setcounter{equation}{\value{parentequation}}%
  \ignorespacesafterend}

\newenvironment{subnumbered*}{%
  \refstepcounter{equation}%
  \protected@edef\theparentequation{\theequation}%
  \setcounter{parentequation}{\value{equation}}%
  \setcounter{equation}{0}%
  \def\theequation{(\theparentequation)\@textsubscript{\footnotesize\arabic{equation}}}%
  \def\tagform@\theequation{%
     \maketag@@@{(\ignorespaces\theparentequation\unskip\@@italiccorr)%
                 \@textsubscript{\footnotesize\arabic{equation}}}}%
  \ignorespaces
}{%
  \setcounter{equation}{\value{parentequation}}%
  \ignorespacesafterend}


\newcommand\marknumberwith{\@ifnextchar*{\@marknumberstar}{\@marknumberwith}}
\def\@marknumberstar*#1{\tag*{(\theequation)#1}}
\def\@marknumberwith#1{\tag{\theequation#1}}


\newcommand\conteqn{
  \tabcolsep\z@
  \tag*{\protect\tabular{c}(\theequation)\\[-5pt]
        \tiny[cont.]\protect\endtabular}}
%==================================================================

%===== FOOTNOTE ===================================================
\def\@makefnmark{\hbox{\,\@textsuperscript{\normalfont\@thefnmark)}}}
%==================================================================

%===== ILLUSTRATIONS LAYOUT =======================================
\setcounter{topnumber}{2}
\renewcommand\topfraction{.8}
\setcounter{bottomnumber}{2}
\renewcommand\bottomfraction{.5}
\setcounter{totalnumber}{3}
\renewcommand\textfraction{.2}
\renewcommand\floatpagefraction{.5}

\setlength\floatsep    {8\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\textfloatsep{8\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\intextsep   {8\p@ \@plus 2\p@ \@minus 2\p@}
%==================================================================

%===== CAPTIONS ===================================================
\renewcommand\figurename{\textsc{Figure}}
\renewcommand\tablename{\textsc{Table}}

\long\def\@caption#1[#2]#3{%
  \par
  \addcontentsline{\csname ext@#1\endcsname}{#1}%
    {\protect\numberline{\csname the#1\endcsname}{\ignorespaces #2}}%
  \begingroup
    \@parboxrestore
    \footnotesize
    \centering
    \@makecaption{\csname fnum@#1\endcsname}{\ignorespaces #3}\par
  \endgroup}
  
\newlength\captionWidth
\setlength\captionWidth{0.9\textwidth}

\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \begin{minipage}{\captionWidth}
  \sbox\@tempboxa{#1. \ #2}%
  \ifdim \wd\@tempboxa >\hsize
    #1. \ #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \end{minipage}
  \vskip\belowcaptionskip}
  
\setlength\belowcaptionskip{10\p@ \@plus 1\p@ \@minus 1\p@}
%==================================================================

%===== TABLE OF CONTENTS ==========================================
\setcounter{tocdepth}{2}

\def\numberline#1{\hb@xt@\@tempdima{#1.\hfil}}

\renewcommand\tableofcontents{%
    \chapter*{\contentsname}
    \vspace*{-5mm}
    {\small
    \@starttoc{toc}}%
    }
    
\renewcommand*\l@chapter[2]{%
  \ifnum \c@tocdepth >\m@ne
    \addpenalty{-\@highpenalty}%
    \vskip 0.5em \@plus 0.2em  %\vskip 0.6em \@plus 0.2em
    \setlength\@tempdima{1.7em}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth \@plus 1.5em
      \parfillskip -\@pnumwidth
      \leavevmode \bfseries
      \advance\leftskip\@tempdima
      \hskip -\leftskip 
      #1\nobreak\hfil \nobreak\hb@xt@\@pnumwidth{\hss #2}\par
      \penalty\@highpenalty
    \endgroup
  \fi}

\renewcommand*\l@section{\@dottedtocline{1}{1.7em}{2.3em}}
\renewcommand*\l@subsection{\@dottedtocline{2}{4.em}{3.em}}
%==================================================================

%===== BIBLIOGRAPHY ===============================================
\renewcommand\and{{\normalfont\rmfamily \protect\lowercase{and} }}

\def\@biblabel#1{#1.}
   
\renewenvironment{thebibliography}[1]
     {%\chapter*{\bibname}%
      %\@mkboth{\MakeUppercase\bibname}{\MakeUppercase\bibname}%
      \setlength\parskip{1.5pt \@plus 0.2pt \@minus 0.2pt}%
      \small
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}
%==================================================================

%===== NAMES ======================================================
%\renewcommand\contentsname{Contents}
%\renewcommand\listfigurename{List of Figures}
%\renewcommand\listtablename{List of Tables}
%\renewcommand\bibname{Bibliography}
%\renewcommand\indexname{Index}
%\renewcommand\figurename{Figure}
%\renewcommand\tablename{Table}
%\renewcommand\partname{Part}
%\renewcommand\chaptername{Chapter}
%\renewcommand\appendixname{Appendix}
%==================================================================

\endinput
